{% extends "ymci:_base.html" %}

{% block main %}
  <article class="block" data-block="rights_per_group"></article>
  <article class="block" data-block="rights_per_user"></article>
  <article class="block" data-block="set_list"></article>
  <article class="block" data-block="levels_list"></article>
  <article class="block" data-block="user_levels_list"></article>
{% end %}
